@@ -29,8 +29,7 @@ def _v3_to_v2_catalog(catalog):
         v2_service = {'type': v3_service['type']}
         try:
             v2_service['name'] = v3_service['name']
-        except KeyError:  # nosec
-            # v3 service doesn't have a name, so v2_service doesn't either.
+        except KeyError:
             pass
 
         # now convert the endpoints. Because in v3 we specify region per
@@ -88,6 +87,7 @@ class _AuthTokenRequest(webob.Request):
 
     _SERVICE_CATALOG_HEADER = 'X-Service-Catalog'
     _TOKEN_AUTH = 'keystone.token_auth'
+    _TOKEN_INFO = 'keystone.token_info'
 
     _CONFIRMED = 'Confirmed'
     _INVALID = 'Invalid'
@@ -223,3 +223,12 @@ class _AuthTokenRequest(webob.Request):
     @token_auth.setter
     def token_auth(self, v):
         self.environ[self._TOKEN_AUTH] = v
+
+    @property
+    def token_info(self):
+        """The raw token dictionary retrieved by the middleware"""
+        return self.environ.get(self._TOKEN_INFO)
+
+    @token_info.setter
+    def token_info(self, v):
+        self.environ[self._TOKEN_INFO] = v
